#!/usr/bin/env python3

from pathlib import Path
from . import __app_name__

app_dir = Path.home() / f'.{__app_name__}'
default_log_csv = app_dir / 'log.csv'
default_supposed_file = app_dir / 'supposed'
csv_headers = ['timestamp', 'supposed', 'event', 'focused']



#!/usr/bin/env python3

from io import StringIO
from datetime import datetime
from argparse import Namespace
from .config import default_log_csv, csv_headers, app_dir, default_supposed_file
import csv


def init_app() -> None:
    if not app_dir.exists():
        app_dir.mkdir()
    # if csv file doesn't exist, create it
    if not default_log_csv.exists():
        with open(default_log_csv, 'w') as f:
            dw = csv.DictWriter(f, fieldnames=csv_headers)
            dw.writeheader()


def log_event(event: str, timestamp: str | None = None, focused: bool = False) -> None:
    """Log event"""
    with default_log_csv.open('a') as f:
        dw = csv.DictWriter(f, fieldnames=csv_headers)
        if timestamp is None:
            timestamp = datetime.now().isoformat()
        dw.writerow(
            {
                'timestamp': timestamp,
                'supposed': get_supposed(),
                'event': event,
                'focused': int(focused),
            }
        )


def get_supposed() -> str:
    """Get supposed"""
    try:
        with default_supposed_file.open() as f:
            return f.readline().strip()
    except FileNotFoundError:
        return ''


def set_supposed(supposed: str) -> None:
    """Set supposed"""
    with default_supposed_file.open('w') as f:
        f.write(supposed)


def process_args_init(args: Namespace):
    """Process command-line arguments for init"""
    init_app()


def process_args_log(args: Namespace):
    """Process command-line arguments for log"""
    log_event(args.event, focused=args.focused)
    if args.focused:
        # print good job and supposed info in green
        print(
            f'''\033[32mGood job! You\'re doing what you\'re supposed to be doing, which is "{get_supposed()}"\033[0m'''
        )
    else:
        # print supposed info in red
        print(
            f'''\033[31mYou\'re not doing what you\'re supposed to be doing, which is "{get_supposed()}"\033[0m'''
        )


def process_args_supposed_get(args: Namespace):
    """Process command-line arguments for supposed"""
    print(f'You\'re supposed to be doing {get_supposed()}')


def process_args_supposed_set(args: Namespace):
    set_supposed(args.supposed)
    print(f'Supposed set to "{get_supposed()}"')



#!/usr/bin/env python3
"""
Author : Xinyuan Chen <45612704+tddschn@users.noreply.github.com>
Date   : 2022-11-09
Purpose: Personal Logger
"""

import argparse
from argparse import ArgumentParser, Namespace
from pathlib import Path
from .config import default_log_csv
from .utils import (
    process_args_init,
    process_args_log,
    process_args_supposed_get,
    process_args_supposed_set,
)


def get_args() -> tuple[ArgumentParser, Namespace]:
    """Get command-line arguments"""

    parser = argparse.ArgumentParser(
        description='Personal Logger',
        formatter_class=argparse.ArgumentDefaultsHelpFormatter,
    )

    sp = parser.add_subparsers()
    parser_init = sp.add_parser('init', help='Initialize the app')
    parser_init.set_defaults(func=process_args_init)
    parser_log = sp.add_parser(
        'log',
        aliases=['l'],
        help='Log what you\'re doing right now',
    )
    parser_log.add_argument(
        'event',
        metavar='THE THING UR DOING RIGHT NOW',
        help='What you\'re doing right now',
    )
    parser_log.add_argument(
        '-f',
        '--focused',
        action='store_true',
        help='Use this flag if you\'re focused on doing what you\'re supposed to do',
    )
    parser_log.set_defaults(func=process_args_log)
    parser_supposed = sp.add_parser(
        'supposed',
        aliases=['s'],
        help='Getting and setting things that you\'re supposed to do',
    )
    # parser_supposed.set_defaults(func=process_args_supposed)
    sp_supposed = parser_supposed.add_subparsers()
    parser_supposed_get = sp_supposed.add_parser(
        'get', help='Get what you\'re supposed to do'
    )
    parser_supposed_get.set_defaults(func=process_args_supposed_get)
    parser_supposed_set = sp_supposed.add_parser(
        'set', help='Set what you\'re supposed to do'
    )
    parser_supposed_set.add_argument(
        'supposed',
        metavar='THING',
        type=str,
        help='What you\'re supposed to do',
    )
    parser_supposed_set.set_defaults(func=process_args_supposed_set)
    return parser, parser.parse_args()


def main():
    """Make a jazz noise here"""

    parser, args = get_args()
    if hasattr(args, 'func'):
        args.func(args)
    else:
        parser.print_help()


if __name__ == '__main__':
    main()
